@@ -1399,249 +1399,6 @@ test_returnValue_list_nodebynode <- function(result, reference, xmlTestSpec, add
 }
 
 
-# test_manualCheck_file ###########################################################################
-
-#' Creates a manual check via tcl/tk interface of created output file
-#'
-#' @param    result             (\code{object}) The result object to be tested.
-#' @param    reference          (\code{object}) The reference object.
-#' @param    xmlTestSpec        (\code{XMLNode}) The XML definition of type 'RTestTest_variable'.
-#' @param    add.desc           (\code{character}) Additional description added to the XML
-#'                              definition.
-#' @param    openrecexp         (\code{code}) Function to open/show reference and expected result.
-#' @param    openrecexp.exec    (\code{logical}) Specify, if the openrecexp-function should be
-#'                              executed by default or only on user decision (by click).
-#'
-#' @seealso \code{\link[XML]{XMLNode-class}}
-#'
-#' @author   Matthias Pfeifer \email{matthias.pfeifer@@roche.com}
-test_manualCheck_file <- function(result, reference, xmlTestSpec=NULL, add.desc = NULL,
-    openrecexp = NULL, openrecexp.exec = FALSE)
-{
-  testmode <- if(!is.null(options("testmode")[[1]])){
-        as.logical(options("testmode"))
-      }else{
-        FALSE
-      }
-
-  if(is.null(xmlTestSpec)){
-    xmlTestSpec <- xmlNode("return-value",attrs=list("compare-type"="equal"))
-  }
-  test.attrs <- xmlAttrs(xmlTestSpec)
-
-  # Check if provided reference is a file or just a description
-  refisfile <- ifelse(file.exists(reference), TRUE, FALSE)
-
-  if(length(reference) == 1 && file.exists(reference)) {
-    refisfile <- TRUE
-    reference.html <- reference
-    reference.txt  <- reference
-  } else {
-    refisfile <- FALSE
-    reference.html <- paste(paste0("* ",reference), collapse = "<br>")
-    reference.txt  <- paste(paste0("* ",reference), collapse = "\n")
-  }
-
-
-
-  # Global settings of the test -------------------------------------------------------------------
-
-  # Open confirmation window to catch user decision about the output
-
-  test.name      <-
-      ifelse("desc" %in% names(test.attrs),
-          test.attrs[["desc"]], "Manual check of created output")
-
-  if(!is.null(add.desc))
-    test.name <- paste0(add.desc," ",test.name)
-
-
-  if(is.null(openrecexp)) {
-    openrecexp <- function() {
-      cat("\n\n-----------------------------------------------------\n\n")
-
-   if( file.exists(result) ){
-
-        cat("RESULT:\n")
-        cat(result,"\n")
-
-        if(file.info(result)$isdir) {
-          tmp <- getwd()
-          setwd(result)
-
-      if(Sys.info()["sysname"]=="Windows")shell.exec(".")
-          setwd(tmp)
-        } else {
-        if(Sys.info()["sysname"]=="Windows")shell.exec(result)
-        }
-    }else{
-      cat("RESULT:\n")
-      cat("not existing")
-    }
-
-      cat("REFERENCE:\n")
-      cat(reference.txt,"\n")
-
-      if(refisfile)
-      if(Sys.info()["sysname"]=="Windows")shell.exec(reference)
-
-      cat("\n\n-----------------------------------------------------\n\n")
-    }
-  }
-
-  if(openrecexp.exec)
-    do.call(openrecexp, list())
-
-  userres <- test_manualCheck_confirmWindow(openrecexp = openrecexp, expectedTxt = reference.txt)
-
-
-  # Perform test ----------------------------------------------------------------------------------
-
-  test_that(test.name, {
-
-        test.info <- paste0(
-            "{",
-            "\"Test\":\"Manual file check\", ",
-            "\"Name\":\"%s\", ",
-            "\"Received\":\"%s\", ",
-            "\"Expected\":\"%s\", ",
-            "\"User decision\":\"%s\", ",
-            "\"User comment\":\"%s\" ",
-            "}")
-
-        do.call(
-            "expect_equal",
-            list(
-                object    = userres$result,
-                expected  = TRUE,
-                tolerance = 1.5e-8,
-                scale     = 1,
-                info      = sprintf(
-                    test.info,
-                    "Created output file as expected - manually checked by tester.",
-                    basename(result),
-                    reference.html,
-                    ifelse(userres$result, "passed", "failed"),
-                    userres$comment
-                )
-            )
-        )
-      })
-}
-
-
-
-
-# test_manualCheck_confirmWindow ##################################################################
-
-#' Creates a Tcl/Tk Window for confirmation of the manual check
-#'
-#' @param    openrecexp (\code{function}) Function to open a window with the received and expected
-#'           values or NULL to hide all.
-#' @param    expectedTxt (\code{character}) Shown as text for the expected vidow.
-#'
-#' @return  (\code{list}) List with elements 'result': TRUE or FALSE depending on the user's
-#'           choice and 'comment': inserted user comment.
-#'
-#'
-#' @section Package dependencies:
-#' The \code{tcltk} package is required. Please install it from CRAN if not in your current library
-#' path.
-#'
-#' @seealso \code{\link[XML]{XMLNode-class}}
-#'
-#' @author   Matthias Pfeifer \email{matthias.pfeifer@@roche.com}
-test_manualCheck_confirmWindow <- function(openrecexp = NULL, expectedTxt = NULL) {
-
-  if(!requireNamespace("tcltk", quietly = TRUE)) {
-    stop("Package 'tcltk' is needed for this function to work. Please install it.", call. = FALSE)
-  }
-
-  testmode <- if(!is.null(options("testmode")[[1]])){
-    as.logical(options("testmode"))
-  }else{
-    FALSE
-  }
-
-  # Initalize variable to store user decisionresult
-  result <- NA
-
-
-  # Create a new Tk toplevel window assigned to win1
-  win <- tcltk::tktoplevel()
-
-  tcltk::tkwm.title(win, "RTest")
-
-
-  tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-
-
-  # Headline
-  txt <- tcltk::tklabel(win, text = "MANUAL CHECK", font = tcltk::tkfont.create(weight="bold"))
-  tcltk::tkgrid(txt, columnspan = 4)
-  tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-
-  if(!is.null(expectedTxt)) {
-    tcltk::tkgrid(tcltk::tklabel(win, text="EXPECTED RESULTS:"), columnspan = 4)
-    tcltk::tkgrid(tcltk::tklabel(win, text=expectedTxt), columnspan = 4)
-    tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-  }
-
-  # Button to open expected/received results via passed function
-  if(!is.null(openrecexp)) {
-    # Create a Tk button whose function (command) is to destroy the window win1
-
-    butRECEXP <- tcltk::tkbutton(win, text = "Open received results (file)", width = 30,
-        command = function() { do.call(openrecexp, list()) })
-
-    tcltk::tkgrid(butRECEXP, columnspan = 4)
-    tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-  }
-
-  # Label
-  txt <- tcltk::tklabel(win, text = "Are the acceptance criteria fulfilled (\"as expected\")?")
-  tcltk::tkgrid(txt, columnspan = 4)
-  tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-
-  # Comment
-  lbl <- tcltk::tklabel(win, text = "Comment")
-  tcltk::tkgrid(lbl, columnspan = 4)
-
-  comment <- tcltk::tclVar("")
-  txtin <- tcltk::tkentry(win, width = 50, textvariable = comment)
-  tcltk::tkgrid(txtin, columnspan = 4)
-  tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-
-  # Buttons
-  # Create a Tk button whose function (command) is to destroy the window win1
-  butYES <- tcltk::tkbutton(win, text = "PASSED", width = 10,
-      command = function() { result <<- TRUE; tcltk::tkdestroy(win) })
-
-  # Create a Tk button whose function (command) is to destroy the window win1
-  butNO <- tcltk::tkbutton(win, text = "FAILED", width = 10,
-      command = function() { result <<- FALSE; tcltk::tkdestroy(win) })
-
-  tcltk::tkgrid(tcltk::tklabel(win, text="   "), butYES, butNO, tcltk::tklabel(win, text="   "))
-  tcltk::tkgrid(tcltk::tklabel(win, text="   "))
-
-  # Destroy action
-  tcltk::tkbind(win, "<Destroy>", function() { if(is.na(result)) result <<- FALSE; tcltk::tkdestroy(win) })
-
-  # Focus on current window
-  tcltk::tkfocus(win)
-
-  if(testmode){
-    tcltk::tkdestroy(win)
-    return(list(result = TRUE, comment = "TRUE by testmode"))
-  }else{
-
-    # Wait on user interaction (i.e. until variable 'result' is set)
-    while(is.na(result)){ Sys.sleep(5) }
-
-    return(list(result = result, comment = tcltk::tclvalue(comment)))
-  }
-}
-
 # test_returnValue_variable #######################################################################
 
 #' Tests an image file with ImageMagick ('RTestTest_image')
